@@ -842,7 +842,7 @@ def parse_to_score_object(music):
             tie_is_in_the_air = 1
         elif toc == Lexer.NOTE and (context in [NOTES, CHORD, START_OF_CHORD]):
             if times:
-                toc_data.m_duration.m_tuple = times
+                toc_data.m_duration.m_tuplet = times
             if context in [NOTES, START_OF_CHORD]:
                 cur_voice.announce_timepos(timepos)
             if relative_mode:
