@@ -512,7 +512,7 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
                 'lf': self.m_t.m_P.m_filename, 
                 'varname': exception.m_mpd_varname})
         else:
-            m.add_text(_('Failed to parse the music for question number %(idx)i in the lesson file "%(lf)s".') % {'idx': self.m_t.m_P._idx+1, 'lf': self.m_t.m_P.m_filename})
+            m.add_text(_('Failed to parse the music for question number %(idx)i in the lesson file "%(lf)s".') % {'idx': idx, 'lf': self.m_t.m_P.m_filename})
         if 'm_mpd_badcode' in dir(exception):
             m.add_nonwrapped_text(exception.m_mpd_badcode)
         m.add_text(_('The exception was caught in\n"%(filename)s", line %(lineno)i.') % {'filename': sourcefile, 'lineno': lineno})
