@@ -18,6 +18,7 @@ import gtk
 
 import gu
 import lessonfile
+import lessonfilegui
 import abstract
 import statistics
 import statisticsviewer
@@ -54,14 +55,8 @@ class Teacher(abstract.Teacher):
 class MultiButton(gtk.Button):
     def __init__(self, label):
         gtk.Button.__init__(self)
-        if isinstance(label, lessonfile.plstring):
-            hp = gu.HarmonicProgressionLabel(label)
-            hp.show_all()
-            self.add(hp)
-        else:
-            l = gtk.Label(label)
-            l.show()
-            self.add(l)
+        l = lessonfilegui.new_labelobject(label)
+        self.add(l)
         self.m_marked_wrong = False
     def mark_wrong(self):
         if self.m_marked_wrong:
@@ -221,16 +216,16 @@ class Gui(abstract.LessonbasedGui):
                     if elem not in v:
                         v.append(elem)
             def xcmp(a, b):
-                return cmp(self.m_t.m_P.blocklists['element'].index(a),
+                try:
+                    return cmp(self.m_t.m_P.blocklists['element'].index(a),
                            self.m_t.m_P.blocklists['element'].index(b))
+                except ValueError:
+                    return cmp(a, b)
             v.sort(xcmp)
             self.m_t.m_P.header.elements = v
         self.g_answer_button_box.empty()
         self.g_answer.foreach(lambda w: w.destroy())
         #
-        if not self.m_t.m_P.header.music_displayer_stafflines:
-            self.m_t.m_P.header.music_displayer_stafflines = 1
-        #
         if self.m_t.m_P.header.have_music_displayer:
             self.g_music_displayer.show()
             self.g_music_displayer.clear(self.m_t.m_P.header.music_displayer_stafflines)
