@@ -154,8 +154,7 @@ class Gui(abstract.LessonbasedGui):
             self.g_bb.initialize(self.m_t.m_P.header.fillnum,
                                  self.m_t.m_P.header.filldir)
             for question in self.m_t.m_P.iterate_questions_with_unique_names():
-                self.g_bb.add(question,
-                      self.m_t.m_P.header.labelformat, self.on_click)
+                self.g_bb.add(question, self.on_click)
         else:
             self.g_bb.initialize(0, 0)
         if self.m_t.m_P and self.m_t.m_custom_mode:
@@ -168,8 +167,7 @@ class Gui(abstract.LessonbasedGui):
                                  self.m_t.m_P.header.filldir)
             self.m_t.check_askfor()
             for question in self.m_t.m_P.iterate_questions_with_unique_names():
-                self.g_select_questions.add(question,
-                      self.m_t.m_statistics.get_label_style())
+                self.g_select_questions.add(question)
         else:
             self.g_select_questions_category_box.hide()
             self.g_select_questions.initialize(0, 0)
@@ -205,7 +203,7 @@ class Gui(abstract.LessonbasedGui):
         self.show_hide_at_question_start_buttons()
         if self.m_t.m_P.header.have_music_displayer:
             self.g_music_displayer.show()
-            self.g_music_displayer.clear()
+            self.g_music_displayer.clear(self.m_t.m_P.header.music_displayer_stafflines)
             self.g_show.hide()
         else:
             self.g_music_displayer.hide()
@@ -304,7 +302,7 @@ class Gui(abstract.LessonbasedGui):
             self.g_show.set_sensitive(False)
             self.g_give_up.set_sensitive(False)
         if self.m_t.m_P.header.have_music_displayer:
-            self.g_music_displayer.clear()
+            self.g_music_displayer.clear(self.m_t.m_P.header.music_displayer_stafflines)
         try:
             g = self.m_t.new_question()
             if g == self.m_t.OK:
@@ -347,7 +345,7 @@ class Gui(abstract.LessonbasedGui):
         if not self.m_t.m_custom_mode:
             self.m_t.m_statistics.reset_session()
         self.g_statview.g_heading.set_text(self.m_t.m_P.header.title)
-        self.g_music_displayer.clear()
+        self.g_music_displayer.clear(self.m_t.m_P.header.music_displayer_stafflines)
         # We only want the Show button if there are any questions that can
         # be displayed.
         if [q for q in self.m_t.m_P.m_questions if isinstance(q.music, lessonfile.MpdDisplayable)] and not self.m_t.m_P.header.have_music_displayer:
@@ -366,7 +364,7 @@ class Gui(abstract.LessonbasedGui):
         self.g_repeat_slowly.set_sensitive(False)
         self.g_repeat_arpeggio.set_sensitive(False)
         if self.m_t.m_P and self.m_t.m_P.header.have_music_displayer:
-            self.g_music_displayer.clear()
+            self.g_music_displayer.clear(self.m_t.m_P.header.music_displayer_stafflines)
         self.g_show.set_sensitive(False)
         self.g_new.set_sensitive(True)
         self.g_give_up.set_sensitive(False)
