@@ -180,16 +180,16 @@ class InstrumentConfigurator(gtk.VBox, cfg.ConfigUtils):
         hbox = gu.bHBox(self)
         hbox.set_spacing(gu.PAD_SMALL)
 
-        self.g_instrsel_high = InstrumentSelector(_("Highest instrument"),
+        self.g_instrsel_high = InstrumentSelector(_("Highest"),
                                                  exname, 'highest_instrument')
         hbox.pack_start(self.g_instrsel_high, False)
         if num == 3:
-            self.g_instrsel_middle = InstrumentSelector(_("Middle instrument"),
+            self.g_instrsel_middle = InstrumentSelector(_("Middle"),
                                             exname, 'middle_instrument')
             hbox.pack_start(self.g_instrsel_middle, False)
         else:
             self.g_instrsel_middle = None
-        self.g_instrsel_low = InstrumentSelector(_("Lowest instrument"),
+        self.g_instrsel_low = InstrumentSelector(_("Lowest"),
                                                 exname, 'lowest_instrument')
         hbox.pack_start(self.g_instrsel_low, False)
         self.update_instrument_override()
