@@ -9,7 +9,7 @@ src.cfg.initialise("default.config", None,
     os.path.join(filesystem.rcfile()))
 import src.i18n
 src.i18n.setup(".")
-import src.rhythm
+import src.abstract
 
 img_str = """%i:<inlinemediaobject>
       <imageobject>
